# fileinfo

> Get information on over 10,000 file extensions right from the terminal

## 💾 Installation

```bash
# clone the repo
$ git clone https://github.com/sdushantha/fileinfo.git
# change the working directory to fileinfo
$ cd fileinfo

# install the requirements
$ pip3 install -r requirements.txt
```


## 📜 License
MIT License

Copyright (c) 2018 Siddharth Dushantha
